## Topsis_Sudhit_102017137

# TOPSIS

Submitted By: Sudhit Soni - 102017137.

Type: Package.

Title: *TOPSIS method for multiple-criteria decision making (MCDM)*.

Version: 1.0.0.

Date: 2022-01-22.

Author: Sudhit Soni.

Maintainer: *Sudhit Soni <ssoni_be20@thapar.edu>*.

Description: *Evaluation of alternatives based on multiple criteria using TOPSIS method.*.

---

## What is TOPSIS?

*Technique for **Order **Preference by **Similarity to **Ideal **S*olution
(TOPSIS) originated in the 1980s as a multi-criteria decision making method.
TOPSIS chooses the alternative of shortest Euclidean distance from the ideal solution,
and greatest distance from the negative-ideal solution.

<br>

## How to install this package:


>> pip install Topsis-Sudhit-102017137


### In Command Prompt


>> topsis data.csv "1,1,1,1,1" "+,+,-,+,-" result.csv


## Input file (data.csv)

The decision matrix should be constructed with each row representing a Model alternative, and each column representing a criterion like Accuracy, R<sup>2</sup>, Root Mean Squared Error, Correlation, and many more.

Fund Name	P1	    P2	    P3	P4	    P5
M1	        0.63	0.4	    6.4	64.4	17.96
M2	        0.85	0.72	3.2	69.6	18.59
M3	        0.94	0.88	4	31	    9.21
M4	        0.68	0.46	5.6	32.4	9.79
M5	        0.69	0.48	5.5	38.5	11.29
M6	        0.7	    0.49	5.7	34.1	10.25
M7	        0.93	0.86	6.6	60.5	17.22
M8	        0.62	0.38	3.6	64.5	17.28


Weights (`weights`) is not already normalised will be normalised later in the code.

Information of benefit positive(+) or negative(-) impact criteria should be provided in `impacts`.

<br>

## Output file (out.csv)

Fund Name	P1	P2	P3	P4	P5	Topsis Score	Rank
M1	        0.77	0.59	3.4	64.7	17.37	0.590504815	3
M2	        0.76	0.58	6.1	51.5	14.74	0.402338394	6
M3	        0.61	0.37	4.2	53.9	14.77	0.406862418	5
M4	        0.7	    0.49	7	34.3	10.62	0.320024918	8
M5	        0.94	0.88	4.4	63.5	17.43	0.699428496	2
M6	        0.93	0.86	6.5	57	    16.32	0.568238573	4
M7	        0.91	0.83	3.2	59.6	16.14	0.757501032	1
M8	        0.67	0.45	7	64.3	18.11	0.327902786	7


<br>
The output file contains columns of input file along with two additional columns having Topsis_score and Rank